==> geopsypack-src-3.3.5.tar.gz: geopsypack-src-3.3.5/QGpCompatibility/src/CompatRefractionSurvey.h <==
/***************************************************************************
**
**  This file is part of QGpCompatibility.
**
**  QGpCompatibility is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  QGpCompatibility is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2004-11-02
**  Copyright: 2004-2019
**    Marc Wathelet
**    Marc Wathelet (ULg, Liège, Belgium)
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef COMPATREFRACTIONSURVEY_H
#define COMPATREFRACTIONSURVEY_H

#include <QGpCoreTools.h>
#include "CompatSrcHodochrone.h"
#include "QGpCompatibilityDLLExport.h"

namespace QGpCompatibility {

/*
class QGPCOMPATIBILITY_EXPORT CompatRefractionSurvey : public QVector<CompatSrcHodochrone>, public XMLClass
{
  TRANSLATIONS( "CompatRefractionSurvey" );
public:
  CompatRefractionSurvey() {}
  virtual ~CompatRefractionSurvey() {}

  int nSrc() const {return count();}
  void setNSrc(int n) {resize(n);}
  
  CompatSrcHodochrone& hodochrone(int is) {return operator[](is);}
  const CompatSrcHodochrone& hodochrone(int is) const {return operator[](is);}
protected:
  virtual const QString& xml_tagName() const {return xmlRefractionSurveyTag;}
  static const QString xmlRefractionSurveyTag;
  virtual void xml_writeChildren(XML_WRITECHILDREN_ARGS) const;
  virtual XMLMember xml_member(XML_MEMBER_ARGS);
};

QGPCOMPATIBILITY_EXPORT QDataStream& operator<< (QDataStream& s, const CompatRefractionSurvey& p);
QGPCOMPATIBILITY_EXPORT QDataStream& operator>> (QDataStream& s, CompatRefractionSurvey& p);
*/

} // namespace QGpCompatibility

#endif // COMPATREFRACTIONSURVEY_H

==> geopsypack-src-3.5.2.tar.gz: geopsypack-src-3.5.2/QGpCompatibility/src/CompatRefractionSurvey.h <==
/***************************************************************************
**
**  This file is part of QGpCompatibility.
**
**  QGpCompatibility is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  QGpCompatibility is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2004-11-02
**  Copyright: 2004-2019
**    Marc Wathelet
**    Marc Wathelet (ULg, Liège, Belgium)
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef COMPATREFRACTIONSURVEY_H
#define COMPATREFRACTIONSURVEY_H

#include <QGpCoreTools.h>
#include "CompatSrcHodochrone.h"
#include "QGpCompatibilityDLLExport.h"

namespace QGpCompatibility {

/*
class QGPCOMPATIBILITY_EXPORT CompatRefractionSurvey : public VectorList<CompatSrcHodochrone>, public XMLClass
{
  TRANSLATIONS( "CompatRefractionSurvey" );
public:
  CompatRefractionSurvey() {}
  virtual ~CompatRefractionSurvey() {}

  int nSrc() const {return count();}
  void setNSrc(int n) {resize(n);}
  
  CompatSrcHodochrone& hodochrone(int is) {return operator[](is);}
  const CompatSrcHodochrone& hodochrone(int is) const {return operator[](is);}
protected:
  virtual const QString& xml_tagName() const {return xmlRefractionSurveyTag;}
  static const QString xmlRefractionSurveyTag;
  virtual void xml_writeChildren(XML_WRITECHILDREN_ARGS) const;
  virtual XMLMember xml_member(XML_MEMBER_ARGS);
};

QGPCOMPATIBILITY_EXPORT QDataStream& operator<< (QDataStream& s, const CompatRefractionSurvey& p);
QGPCOMPATIBILITY_EXPORT QDataStream& operator>> (QDataStream& s, CompatRefractionSurvey& p);
*/

} // namespace QGpCompatibility

#endif // COMPATREFRACTIONSURVEY_H
